@@ -1,7 +1,7 @@
 __version_info__ = {
     'major': 3,
     'minor': 0,
-    'micro': 0,
+    'patch': 1,
     'releaselevel': 'final',
     'serial': 0
 }
@@ -10,8 +10,8 @@ __version_info__ = {
 def get_version(short=False):
     assert __version_info__['releaselevel'] in ('alpha', 'beta', 'final')
     vers = ["%(major)i.%(minor)i" % __version_info__, ]
-    if __version_info__['micro']:
-        vers.append(".%(micro)i" % __version_info__)
+    if __version_info__['patch']:
+        vers.append(".%(patch)i" % __version_info__)
     if __version_info__['releaselevel'] != 'final' and not short:
         vers.append(
             '%s%i' % (
