@@ -1,6 +1,8 @@
-from django.conf import settings
 from pydoc import locate
 
+from django.conf import settings
+
+
 # The 'correct' configuration for Explorer looks like:
 
 # EXPLORER_CONNECTIONS = {
@@ -18,31 +20,31 @@ EXPLORER_DEFAULT_CONNECTION = getattr(
 EXPLORER_SQL_BLACKLIST = getattr(
     settings, 'EXPLORER_SQL_BLACKLIST',
     (
-        'ALTER',
-        'RENAME ',
-        'DROP',
-        'TRUNCATE',
-        'INSERT INTO',
-        'UPDATE',
-        'REPLACE',
+        # DML
+        'COMMIT',
         'DELETE',
-        'CREATE TABLE',
+        'INSERT',
+        'MERGE',
+        'REPLACE',
+        'ROLLBACK',
+        'SET',
+        'START',
+        'UPDATE',
+        'UPSERT',
+
+        # DDL
+        'ALTER',
+        'CREATE',
+        'DROP',
+        'RENAME',
+        'TRUNCATE',
+
+        # DCL
         'GRANT',
-        'OWNER TO',
-        'SET'
+        'REVOKE',
     )
 )
 
-EXPLORER_SQL_WHITELIST = getattr(
-    settings,
-    'EXPLORER_SQL_WHITELIST',
-    (
-        'CREATED',
-        'UPDATED',
-        'DELETED',
-        'REGEXP_REPLACE'
-    )
-)
 
 EXPLORER_DEFAULT_ROWS = getattr(settings, 'EXPLORER_DEFAULT_ROWS', 1000)
 
@@ -124,8 +126,19 @@ ENABLE_TASKS = getattr(settings, "EXPLORER_TASKS_ENABLED", False)
 S3_ACCESS_KEY = getattr(settings, "EXPLORER_S3_ACCESS_KEY", None)
 S3_SECRET_KEY = getattr(settings, "EXPLORER_S3_SECRET_KEY", None)
 S3_BUCKET = getattr(settings, "EXPLORER_S3_BUCKET", None)
+S3_LINK_EXPIRATION: int = getattr(settings, "EXPLORER_S3_LINK_EXPIRATION", 3600)
 FROM_EMAIL = getattr(
     settings, 'EXPLORER_FROM_EMAIL', 'django-sql-explorer@example.com'
 )
+S3_REGION = getattr(settings, "EXPLORER_S3_REGION", "us-east-1")
+S3_ENDPOINT_URL = getattr(settings, "EXPLORER_S3_ENDPOINT_URL", None)
 
 UNSAFE_RENDERING = getattr(settings, "EXPLORER_UNSAFE_RENDERING", False)
+
+EXPLORER_CHARTS_ENABLED = getattr(settings, "EXPLORER_CHARTS_ENABLED", False)
+
+# If set to True will autorun queries when viewed which is the historical behavior
+# Default to True if not set in order to be backwards compatible
+# If set to False will not autorun queries containing parameters when viewed
+# - user will need to run by clicking the Save & Run Button to execute
+EXPLORER_AUTORUN_QUERY_WITH_PARAMS = getattr(settings, "EXPLORER_AUTORUN_QUERY_WITH_PARAMS", True)
