@@ -2,23 +2,19 @@ import logging
 from time import time
 
 from django.conf import settings
-from django.db import models, DatabaseError, transaction
+from django.core.exceptions import ValidationError
+from django.db import DatabaseError, models, transaction
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from explorer import app_settings
 from explorer.utils import (
-    passes_blacklist,
-    swap_params,
-    extract_params,
-    shared_dict_update,
-    get_s3_bucket,
-    get_params_for_url,
-    get_valid_connection
+    extract_params, get_params_for_url, get_s3_bucket, get_valid_connection, passes_blacklist, s3_url,
+    shared_dict_update, swap_params,
 )
 
-MSG_FAILED_BLACKLIST = "Query failed the SQL blacklist: %s"
 
+MSG_FAILED_BLACKLIST = "Query failed the SQL blacklist: %s"
 
 logger = logging.getLogger(__name__)
 
@@ -78,6 +74,18 @@ class Query(models.Model):
         return swap_params(self.sql, self.available_params())
 
     def execute_query_only(self):
+        # check blacklist every time sql is run to catch parameterized SQL
+        passes_blacklist_flag, failing_words = self.passes_blacklist()
+
+        error = MSG_FAILED_BLACKLIST % ', '.join(
+            failing_words) if not passes_blacklist_flag else None
+
+        if error:
+            raise ValidationError(
+                error,
+                code="InvalidSql"
+            )
+
         return QueryResult(
             self.final_sql(), get_valid_connection(self.connection)
         )
@@ -137,13 +145,13 @@ class Query(models.Model):
     def snapshots(self):
         if app_settings.ENABLE_TASKS:
             b = get_s3_bucket()
-            keys = b.list(prefix=f'query-{self.id}/snap-')
-            keys_s = sorted(keys, key=lambda k: k.last_modified)
+            objects = b.objects.filter(Prefix=f'query-{self.id}/snap-')
+            objects_s = sorted(objects, key=lambda k: k.last_modified)
             return [
                 SnapShot(
-                    k.generate_url(expires_in=0, query_auth=False),
-                    k.last_modified
-                ) for k in keys_s
+                    s3_url(b, o.key),
+                    o.last_modified
+                ) for o in objects_s
             ]
 
 
@@ -155,7 +163,6 @@ class SnapShot:
 
 
 class QueryLog(models.Model):
-
     sql = models.TextField(blank=True)
     query = models.ForeignKey(
         Query,
@@ -212,19 +219,30 @@ class QueryResult:
         return [str(h) for h in self.headers]
 
     def _get_headers(self):
-        return [ColumnHeader(d[0]) for d in self._description] if self._description else [ColumnHeader('--')]
+        return [
+            ColumnHeader(d[0]) for d in self._description
+        ] if self._description else [ColumnHeader('--')]
 
     def _get_numerics(self):
         if hasattr(self.connection.Database, "NUMBER"):
-            return [ix for ix, c in enumerate(self._description) if hasattr(c, 'type_code') and c.type_code in self.connection.Database.NUMBER.values]
+            return [
+                ix for ix, c in enumerate(self._description)
+                if hasattr(c, 'type_code') and c.type_code in self.connection.Database.NUMBER.values
+            ]
         elif self.data:
             d = self.data[0]
-            return [ix for ix, _ in enumerate(self._description) if not isinstance(d[ix], str) and str(d[ix]).isnumeric()]
+            return [
+                ix for ix, _ in enumerate(self._description)
+                if not isinstance(d[ix], str) and str(d[ix]).isnumeric()
+            ]
         return []
 
     def _get_transforms(self):
         transforms = dict(app_settings.EXPLORER_TRANSFORMS)
-        return [(ix, transforms[str(h)]) for ix, h in enumerate(self.headers) if str(h) in transforms.keys()]
+        return [
+            (ix, transforms[str(h)])
+            for ix, h in enumerate(self.headers) if str(h) in transforms.keys()
+        ]
 
     def column(self, ix):
         return [r[ix] for r in self.data]
